@@ -3,6 +3,7 @@ API module
 """
 
 from pathlib import Path, PurePath
+from typing import Optional
 from typing import Union
 
 from face_group.utils import (_copy_images_by_dict,
@@ -15,6 +16,7 @@ def process_images(
     output_dir: Union[str, PurePath],
     verbose: bool = False,
     model: str = "hog",
+    cpus: int = 1
 ) -> None:
     """Про"""
     input_dir = Path(input_dir)
@@ -23,8 +25,12 @@ def process_images(
     if not output_dir.exists():
         output_dir.mkdir()
 
-    np_face, np_path = _get_encodings_from_image_dir(input_dir, verbose, model)
+    np_face, np_path = _get_encodings_from_image_dir(input_dir, verbose, model, cpus)
 
     face_dict = _sort_path_by_encodings(np_face, np_path)
 
-    _copy_images_by_dict(face_dict, input_dir, output_dir)
+    _copy_images_by_dict(face_dict, input_dir, output_dir, verbose)
+
+
+if __name__ == "__main__":
+    process_images("/home/irlirion/PycharmProjects/face-group/resources", "out")
